@@ -49,6 +49,7 @@ QWidget * FEDelegate::createEditor(QWidget *parent, const QStyleOptionViewItem &
 
 	if (index.column() == COL_FILE) {
 		FileChooser * fch = new FileChooser(parent);
+		fch->setOptions(QFileDialog::DontUseNativeDialog | QFileDialog::DontResolveSymlinks); // Crashes if use the KDE dialog
 		fch->setText( index.model()->data(index, Qt::DisplayRole).toString() );
 		return fch;
 	} 
@@ -174,7 +175,7 @@ void FavoriteEditor::setData( FavoriteList list ) {
 		table->setItem(n, COL_FILE, file_item);
 	}
 
-	table->resizeColumnsToContents();
+	//table->resizeColumnsToContents();
 
 	//table->setCurrentCell(0, 0);
 	table->setCurrentCell(table->rowCount()-1, 0);
