@@ -90,7 +90,7 @@ QString Helper::timeForJumps(int secs) {
 // This function has been copied (and modified a little bit) from Scribus (program under GPL license):
 // http://docs.scribus.net/devel/util_8cpp-source.html#l00112
 QString Helper::shortPathName(QString long_path) {
-	if ((QSysInfo::WindowsVersion >= QSysInfo::WV_NT) && (QFile::exists(long_path))) {
+	if (QFile::exists(long_path)) {
 		QString short_path = long_path;
 
 		const int max_path = 4096;
