@@ -1,5 +1,5 @@
 /*  smplayer, GUI front-end for mplayer.
-    Copyright (C) 2006-2009 Ricardo Villalba <rvm@escomposlinux.org>
+    Copyright (C) 2006-2012 Ricardo Villalba <rvm@users.sourceforge.net>
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -37,6 +37,10 @@
 #include <QTimer>
 #endif
 
+#if LOGO_ANIMATION
+#include <QPropertyAnimation>
+#endif
+
 Screen::Screen(QWidget* parent, Qt::WindowFlags f) : QWidget(parent, f ) 
 {
 	setMouseTracking(TRUE);
@@ -261,9 +265,33 @@ void MplayerWindow::retranslateStrings() {
 #endif
 }
 
-void MplayerWindow::showLogo( bool b)
-{
-	if (b) logo->show(); else logo->hide();
+void MplayerWindow::setLogoVisible( bool b) {
+#if !LOGO_ANIMATION
+	logo->setVisible(b);
+#else
+	if (!animated_logo) {
+		logo->setVisible(b);
+	} else {
+		if (b) {
+			logo->show();
+			QPropertyAnimation * animation = new QPropertyAnimation(logo, "pos");
+			animation->setDuration(200);
+			animation->setEasingCurve(QEasingCurve::OutBounce);
+			animation->setStartValue(QPoint(logo->x(), 0 - logo->y()));
+			animation->setEndValue(logo->pos());
+			animation->start();
+		} else {
+			QPropertyAnimation * animation = new QPropertyAnimation(logo, "pos");
+			animation->setDuration(200);
+			animation->setEasingCurve(QEasingCurve::OutBounce);
+			animation->setEndValue(QPoint(width(), logo->y()));
+			animation->setStartValue(logo->pos());
+			animation->start();
+			connect(animation, SIGNAL(finished()), logo, SLOT(hide()));
+			//logo->hide();
+		}
+	}
+#endif
 }
 
 /*
