@@ -38,6 +38,8 @@
 #include "retrieveyoutubeurl.h"
 #endif
 
+#define CURRENT_CONFIG_VERSION 1
+
 using namespace Global;
 
 Preferences::Preferences() {
@@ -67,6 +69,8 @@ void Preferences::reset() {
        General
        ******* */
 
+	config_version = CURRENT_CONFIG_VERSION;
+
 #if defined(Q_OS_WIN) || defined(Q_OS_OS2)
 	mplayer_bin= "mplayer/mplayer.exe";
 #else
@@ -193,6 +197,7 @@ void Preferences::reset() {
 
 #ifdef YOUTUBE_SUPPORT
 	yt_quality = RetrieveYoutubeUrl::MP4_720p;
+	yt_user_agent = QString::null;
 #endif
 
 
@@ -383,6 +388,10 @@ void Preferences::reset() {
 	auto_add_to_playlist = true;
 	add_to_playlist_consecutive_files = false;
 
+#if LOGO_ANIMATION
+	animated_logo = true;
+#endif
+
 
     /* ********
        TV (dvb)
@@ -400,7 +409,7 @@ void Preferences::reset() {
 
 	latest_dir = QDir::homePath();
 	last_dvd_directory="";
-
+	save_dirs = true;
 
     /* **************
        Initial values
@@ -491,6 +500,8 @@ void Preferences::save() {
 
 	set->beginGroup( "general");
 
+	set->setValue("config_version", config_version);
+
 	set->setValue("mplayer_bin", mplayer_bin);
 	set->setValue("driver/vo", vo);
 	set->setValue("driver/audio_output", ao);
@@ -604,12 +615,15 @@ void Preferences::save() {
 	set->setValue("cache_for_audiocds", cache_for_audiocds);
 	set->setValue("cache_for_tv", cache_for_tv);
 
-#ifdef YOUTUBE_SUPPORT
-	set->setValue("youtube_quality", yt_quality);
-#endif
-
 	set->endGroup(); // performance
 
+#ifdef YOUTUBE_SUPPORT
+	set->beginGroup("youtube");
+	set->setValue("quality", yt_quality);
+	set->setValue("user_agent", yt_user_agent);
+	set->endGroup();
+#endif
+
 
     /* *********
        Subtitles
@@ -785,8 +799,12 @@ void Preferences::save() {
 	set->setValue("reported_mplayer_is_old", reported_mplayer_is_old);
 #endif
 
-    set->setValue("auto_add_to_playlist", auto_add_to_playlist);
-    set->setValue("add_to_playlist_consecutive_files", add_to_playlist_consecutive_files);
+	set->setValue("auto_add_to_playlist", auto_add_to_playlist);
+	set->setValue("add_to_playlist_consecutive_files", add_to_playlist_consecutive_files);
+
+#if LOGO_ANIMATION
+	set->setValue("animated_logo", animated_logo);
+#endif
 
 	set->endGroup(); // gui
 
@@ -807,8 +825,14 @@ void Preferences::save() {
        *********** */
 
 	set->beginGroup( "directories");
-	set->setValue("latest_dir", latest_dir);
-	set->setValue("last_dvd_directory", last_dvd_directory);
+	if (save_dirs) {
+		set->setValue("latest_dir", latest_dir);
+		set->setValue("last_dvd_directory", last_dvd_directory);
+	} else {
+		set->setValue("latest_dir", "");
+		set->setValue("last_dvd_directory", "");
+	}
+	set->setValue("save_dirs", save_dirs);
 	set->endGroup(); // directories
 
 
@@ -917,6 +941,8 @@ void Preferences::load() {
 
 	set->beginGroup( "general");
 
+	config_version = set->value("config_version", 0).toInt();
+
 	mplayer_bin = set->value("mplayer_bin", mplayer_bin).toString();
 	vo = set->value("driver/vo", vo).toString();
 	ao = set->value("driver/audio_output", ao).toString();
@@ -1032,12 +1058,15 @@ void Preferences::load() {
 	cache_for_audiocds = set->value("cache_for_audiocds", cache_for_audiocds).toInt();
 	cache_for_tv = set->value("cache_for_tv", cache_for_tv).toInt();
 
-#ifdef YOUTUBE_SUPPORT
-	yt_quality = set->value("youtube_quality", yt_quality).toInt();
-#endif
-
 	set->endGroup(); // performance
 
+#ifdef YOUTUBE_SUPPORT
+	set->beginGroup("youtube");
+	yt_quality = set->value("quality", yt_quality).toInt();
+	yt_user_agent = set->value("user_agent", yt_user_agent).toString();
+	set->endGroup();
+#endif
+
 
     /* *********
        Subtitles
@@ -1221,6 +1250,10 @@ void Preferences::load() {
 	auto_add_to_playlist = set->value("auto_add_to_playlist", auto_add_to_playlist).toBool();
 	add_to_playlist_consecutive_files = set->value("add_to_playlist_consecutive_files", add_to_playlist_consecutive_files).toBool();
 
+#if LOGO_ANIMATION
+	animated_logo = set->value("animated_logo", animated_logo).toBool();
+#endif
+
 	set->endGroup(); // gui
 
 
@@ -1241,8 +1274,11 @@ void Preferences::load() {
        *********** */
 
 	set->beginGroup( "directories");
-	latest_dir = set->value("latest_dir", latest_dir).toString();
-	last_dvd_directory = set->value("last_dvd_directory", last_dvd_directory).toString();
+	save_dirs = set->value("save_dirs", save_dirs).toBool();
+	if (save_dirs) {
+		latest_dir = set->value("latest_dir", latest_dir).toString();
+		last_dvd_directory = set->value("last_dvd_directory", last_dvd_directory).toString();
+	}
 	set->endGroup(); // directories
 
 
@@ -1338,6 +1374,16 @@ void Preferences::load() {
        ******* */
 
 	filters->load(set);
+
+	// Fix some values if config is old
+	if (config_version < CURRENT_CONFIG_VERSION) {
+		qDebug("Preferences::load: config version is old, updating it");
+		config_version = CURRENT_CONFIG_VERSION;
+		/*
+		iconset = "Nuvola";
+		yt_user_agent = "Mozilla/5.0 (compatible; Googlebot/2.1; +http://www.google.com/bot.html)";
+		*/
+	}
 }
 
 #endif // NO_USE_INI_FILES
